@@ -24,6 +24,20 @@ use Daje::Workflow::Errors::Error;
 #
 #    my $context->{context}->{some_key_needed_by_some_activity}="";
 #
+#    my $context->{context}-{workflow}->{workflow} = "Workflow name";
+#
+#    my $context->{context}-{workflow}->{activity} = "Name of activity";
+#
+#    my $context->{context}-{workflow}->{workflow_pkey} = "If not 0 workflow will be loaded";
+#
+#    If workflow_pkey == 0 but connector_fkey > 0 and connector != "" connector data will
+#    be used to try to load the workflow. If no workflow is found a new will be created.
+#
+#    my $context->{context}-{workflow}->{connector_fkey} = Number;
+#
+#    my $context->{context}-{workflow}->{connector} = "If not 0 workflow will be loaded";
+#
+#
 #    my $workflow = Daje::Workflow->new(
 #         pg            => $pg,
 #         loader        => $loader->loader,
@@ -53,7 +67,7 @@ use Daje::Workflow::Errors::Error;
 # janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
 #
 
-our $VERSION = "0.13";
+our $VERSION = "0.15";
 
 has 'workflow_name';    #
 has 'workflow_pkey';    #
@@ -217,6 +231,8 @@ __END__
 
 
 
+
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
@@ -236,6 +252,20 @@ Daje::Workflow - It's a simple workflow engine
 
    my $context->{context}->{some_key_needed_by_some_activity}="";
 
+   my $context->{context}-{workflow}->{workflow} = "Workflow name";
+
+   my $context->{context}-{workflow}->{activity} = "Name of activity";
+
+   my $context->{context}-{workflow}->{workflow_pkey} = "If not 0 workflow will be loaded";
+
+   If workflow_pkey == 0 but connector_fkey > 0 and connector != "" connector data will
+   be used to try to load the workflow. If no workflow is found a new will be created.
+
+   my $context->{context}-{workflow}->{connector_fkey} = Number;
+
+   my $context->{context}-{workflow}->{connector} = "If not 0 workflow will be loaded";
+
+
    my $workflow = Daje::Workflow->new(
         pg            => $pg,
         loader        => $loader->loader,
